Bump version
[libdcp.git] / src / dcp.h
index 42c0c6d9b3efd70c0793d78a111b9600a249b606..635a972d65a07c3e961abaacd21741effb043a02 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
 #include <boost/shared_ptr.hpp>
 #include <boost/signals2.hpp>
 #include "types.h"
+#include "certificates.h"
 
 namespace xmlpp {
-       class Node;
+       class Document;
+       class Element;
 }
 
 /** @brief Namespace for everything in libdcp */
@@ -43,15 +45,20 @@ class PictureAsset;
 class SoundAsset;
 class SubtitleAsset;
 class Reel;
-class AssetMap;
 class CPL;
 class XMLMetadata;
+class Signer;
+class KDM;
+
+namespace parse {
+       class AssetMap;
+}
 
 /** @class DCP
  *  @brief A class to create or read a DCP.
  */
        
-class DCP
+class DCP : public boost::noncopyable
 {
 public:
        /** Construct a DCP.  You can pass an existing DCP's directory
@@ -60,22 +67,23 @@ public:
         *
         *  @param directory Directory containing the DCP's files.
         */
-       DCP (std::string directory);
+       DCP (boost::filesystem::path directory);
+
+       void read (bool require_mxfs = true);
 
/** Read an existing DCP's data.
         *
         *  The DCP's XML metadata will be examined, and you can then look at the contents
         *  of the DCP.
-        *
-        *  @param require_mxfs true to throw an exception if MXF files are missing; setting to false
-        *  can be useful for testing, but normally it should be set to true.
         */
-       void read (bool require_mxfs = true);
+       void read_assets ();
+
+       void read_cpls (bool require_mxfs = true);
 
        /** Write the required XML files to the directory that was
         *  passed into the constructor.
         */
-       void write_xml (XMLMetadata const &) const;
+       void write_xml (bool interop, XMLMetadata const &, boost::shared_ptr<const Signer> signer = boost::shared_ptr<const Signer> ()) const;
 
        /** Compare this DCP with another, according to various options.
         *  @param other DCP to compare this one to.
@@ -90,10 +98,24 @@ public:
        void add_cpl (boost::shared_ptr<CPL> cpl);
 
        /** @return The list of CPLs in this DCP */
-       std::list<boost::shared_ptr<const CPL> > cpls () const {
+       std::list<boost::shared_ptr<CPL> > cpls () const {
                return _cpls;
        }
 
+       /** Add another DCP as a source of assets for this DCP.  This should be called before
+        *  ::read() on the DCP that needs the extra assets.  For example
+        *
+        *  DCP original_version ("my_dcp_OV");
+        *  DCP supplemental ("my_dcp_VF");
+        *  supplemental.add_assets_from (original_version);
+        *  supplemental.read ();
+        */
+       void add_assets_from (libdcp::DCP const &);
+
+       bool encrypted () const;
+
+       void add_kdm (KDM const &);
+
        /** Emitted with a parameter between 0 and 1 to indicate progress
         *  for long jobs.
         */
@@ -104,7 +126,7 @@ private:
        /** Write the PKL file.
         *  @param pkl_uuid UUID to use.
         */
-       std::string write_pkl (std::string pkl_uuid, XMLMetadata const &) const;
+       std::string write_pkl (std::string pkl_uuid, bool, XMLMetadata const &, boost::shared_ptr<const Signer>) const;
        
        /** Write the VOLINDEX file */
        void write_volindex () const;
@@ -113,9 +135,9 @@ private:
         *  @param pkl_uuid UUID of our PKL.
         *  @param pkl_length Length of our PKL in bytes.
         */
-       void write_assetmap (std::string pkl_uuid, int pkl_length, XMLMetadata const &) const;
+       void write_assetmap (std::string pkl_uuid, int pkl_length, bool, XMLMetadata const &) const;
 
-       /** @return Assets in all this CPLs in this DCP */
+       /** @return Assets in all the CPLs in this DCP */
        std::list<boost::shared_ptr<const Asset> > assets () const;
 
        struct Files {
@@ -124,10 +146,14 @@ private:
                std::string asset_map;
        };
 
+       Files _files;
+
        /** the directory that we are writing to */
-       std::string _directory;
+       boost::filesystem::path _directory;
        /** our CPLs */
-       std::list<boost::shared_ptr<const CPL> > _cpls;
+       std::list<boost::shared_ptr<CPL> > _cpls;
+
+       std::list<PathAssetMap> _asset_maps;
 };
 
 }
@@ -60,22 +67,23 @@ public:
 
-       /** Read an existing DCP's data.
+       /** Read an existing DCP's assets.
         *
         *  The DCP's XML metadata will be examined, and you can then look at the contents